@@ -204,6 +204,8 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
     if (pcd_table[i] == (PCDTable *) NULL)
       {
         buffer=(unsigned char *) RelinquishMagickMemory(buffer);
+        for (j=0; j < i; j++)
+          pcd_table[j]=(PCDTable *) RelinquishMagickMemory(pcd_table[j]);
         ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
           image->filename);
       }
@@ -215,6 +217,8 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
       if (r->length > 16)
         {
           buffer=(unsigned char *) RelinquishMagickMemory(buffer);
+          for (j=0; j <= i; j++)
+            pcd_table[j]=(PCDTable *) RelinquishMagickMemory(pcd_table[j]);
           return(MagickFalse);
         }
       PCDGetBits(16);
@@ -873,15 +877,9 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->colorspace=YCCColorspace;
   if (LocaleCompare(image_info->magick,"PCDS") == 0)
     (void) SetImageColorspace(image,sRGBColorspace,exception);
-  if ((image_info->number_scenes != 0) && (image_info->scene != 0))
-    {
+  if (image_info->scene != 0)
+    for (i=0; i < (ssize_t) image_info->scene; i++)
       AppendImageToList(&image,CloneImage(image,0,0,MagickTrue,exception));
-      AppendImageToList(&image,CloneImage(image,0,0,MagickTrue,exception));
-      AppendImageToList(&image,CloneImage(image,0,0,MagickTrue,exception));
-      AppendImageToList(&image,CloneImage(image,0,0,MagickTrue,exception));
-      AppendImageToList(&image,CloneImage(image,0,0,MagickTrue,exception));
-      AppendImageToList(&image,CloneImage(image,0,0,MagickTrue,exception));
-    }
   return(GetFirstImageInList(image));
 }
 
