@@ -253,7 +253,6 @@ static void ReadPSInfo(const ImageInfo *image_info,Image *image,
     hex_digits[256];
 
   unsigned long
-    extent,
     spotcolor;
 
   (void) memset(&bounds,0,sizeof(bounds));
@@ -286,7 +285,6 @@ static void ReadPSInfo(const ImageInfo *image_info,Image *image,
   hex_digits[(int) 'D']=13;
   hex_digits[(int) 'E']=14;
   hex_digits[(int) 'F']=15;
-  extent=0;
   priority=0;
   *version='\0';
   spotcolor=0;
@@ -342,9 +340,9 @@ static void ReadPSInfo(const ImageInfo *image_info,Image *image,
     if (CompareMagickByteBuffer(&buffer,DocumentProcessColors,length) != MagickFalse)
       {
         p=GetMagickByteBufferDatum(&buffer);
-        if ((GlobExpression(p,"*Cyan*",MagickTrue) != MagickFalse) ||
-            (GlobExpression(p,"*Magenta*",MagickTrue) != MagickFalse) ||
-            (GlobExpression(p,"*Yellow*",MagickTrue) != MagickFalse))
+        if ((strcasestr(p,"Cyan") != (char *) NULL) ||
+            (strcasestr(p,"Magenta") != (char *) NULL) ||
+            (strcasestr(p,"Yellow") != (char *) NULL))
           ps_info->cmyk=MagickTrue;
       }
     if (CompareMagickByteBuffer(&buffer,CMYKCustomColor,strlen(CMYKCustomColor)) != MagickFalse)
@@ -412,10 +410,14 @@ static void ReadPSInfo(const ImageInfo *image_info,Image *image,
         unsigned char
           *q;
 
+        unsigned long
+          extent;
+
         /*
           Read Photoshop profile.
         */
         p=GetMagickByteBufferDatum(&buffer);
+        extent=0;
         count=(ssize_t) sscanf(p,PhotoshopProfile " %lu",&extent);
         if ((count != 1) || (extent == 0))
           continue;
@@ -430,7 +432,7 @@ static void ReadPSInfo(const ImageInfo *image_info,Image *image,
           if (c == EOF)
             break;
           *q++=(unsigned char) c;
-          extent-=2;
+          extent-=MagickMin(extent,2);
         }
         SetStringInfoLength(ps_info->photoshop_profile,length);
         continue;
@@ -470,7 +472,7 @@ static void ReadPSInfo(const ImageInfo *image_info,Image *image,
           &bounds.x1,&bounds.y1,&bounds.x2,&bounds.y2);
         i=1;
       }
-    if (CompareMagickByteBuffer(&buffer,PageMedia,strlen(PageMedia)) == 0)
+    if (CompareMagickByteBuffer(&buffer,PageMedia,strlen(PageMedia)) != MagickFalse)
       {
         p=GetMagickByteBufferDatum(&buffer);
         count=(ssize_t) sscanf(p,PageMedia " %lf %lf %lf %lf",
@@ -608,8 +610,10 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (image_info->page != (char *) NULL)
     (void) ParseAbsoluteGeometry(image_info->page,&page);
   resolution=image->resolution;
-  page.width=(size_t) ceil((double) (page.width*resolution.x/delta.x)-0.5);
-  page.height=(size_t) ceil((double) (page.height*resolution.y/delta.y)-0.5);
+  page.width=(size_t) ((ssize_t) ceil((double) (page.width*resolution.x/
+    delta.x)-0.5));
+  page.height=(size_t) ((ssize_t) ceil((double) (page.height*resolution.y/
+    delta.y)-0.5));
   /*
     Determine page geometry from the Postscript bounding box.
   */
@@ -625,10 +629,10 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         info.bounds.x2-info.bounds.x1,info.bounds.y2-info.bounds.y1,
         info.bounds.x1,info.bounds.y1);
       (void) SetImageProperty(image,"ps:HiResBoundingBox",geometry,exception);
-      page.width=(size_t) ceil((double) ((info.bounds.x2-info.bounds.x1)*
-        resolution.x/delta.x)-0.5);
-      page.height=(size_t) ceil((double) ((info.bounds.y2-info.bounds.y1)*
-        resolution.y/delta.y)-0.5);
+      page.width=(size_t) ((ssize_t) ceil((double) ((info.bounds.x2-
+        info.bounds.x1)*resolution.x/delta.x)-0.5));
+      page.height=(size_t) ((ssize_t) ceil((double) ((info.bounds.y2-
+        info.bounds.y1)*resolution.y/delta.y)-0.5));
     }
   fitPage=MagickFalse;
   option=GetImageOption(image_info,"eps:fit-page");
@@ -648,10 +652,10 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
           image=DestroyImage(image);
           return((Image *) NULL);
         }
-      page.width=(size_t) ceil((double) (page.width*image->resolution.x/delta.x)
-        -0.5);
-      page.height=(size_t) ceil((double) (page.height*image->resolution.y/
-        delta.y) -0.5);
+      page.width=(size_t) ((ssize_t) ceil((double) (page.width*
+        image->resolution.x/delta.x)-0.5));
+      page.height=(size_t) ((ssize_t) ceil((double) (page.height*
+        image->resolution.y/delta.y) -0.5));
       page_geometry=DestroyString(page_geometry);
       fitPage=MagickTrue;
     }
